@@ -6,7 +6,7 @@ Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 DESCRIPTION
 
@@ -81,7 +81,7 @@ use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 my $LOADER = Mojo::Loader->new;
 
 has _ua => sub { Mojo::UserAgent->new };
@@ -95,47 +95,57 @@ See L</SYNOPSIS>.
 =cut
 
 sub embed_link {
-  my($self, $c, $url, $cb) = @_;
-  my $type;
+  my ($self, $c, $url, $cb) = @_;
 
   $url = Mojo::URL->new($url) unless ref $url;
 
-  if(my $type = lc $url->host) {
+  if (my $type = lc $url->host) {
     $type =~ s/^(?:www|my)\.//;
     $type =~ s/\.\w+$//;
-    return $c if $self->_new_link_object($type => $c, { url => $url }, $cb);
+    return $c if $self->_new_link_object($type => $c, {url => $url}, $cb);
+  }
+  if ($url->path =~ m!\.(?:jpg|png|gif)$!i) {
+    return $c if $self->_new_link_object(image => $c, {url => $url}, $cb);
+  }
+  if ($url->path =~ m!\.(?:mpg|mpeg|mov|mp4|ogv)$!i) {
+    return $c if $self->_new_link_object(video => $c, {url => $url}, $cb);
   }
 
-  if($url->path =~ m!\.(?:jpg|png|gif)$!i) {
-    return $c if $self->_new_link_object(image => $c, { url => $url }, $cb);
-  }
+  return $self->_fallback($c, $url, $cb);
+}
 
-  if($url->path =~ m!\.(?:mpg|mpeg|mov|mp4|ogv)$!i) {
-    return $c if $self->_new_link_object(video => $c, { url => $url }, $cb);
-  }
+sub _fallback {
+  my ($self, $c, $url, $cb) = @_;
 
-  $self->_ua->head($url, sub {
-    my($ua, $tx) = @_;
-    my $ct = $tx->res->headers->content_type || '';
-    return $self->_new_link_object(image => $c, { url => $url, _tx => $tx }, $cb) if $ct =~ m!^image/!;
-    return $self->_new_link_object(video => $c, { url => $url, _tx => $tx }, $cb) if $ct =~ m!^video/!;
-    return $self->_new_link_object(text => $c, { url => $url, _tx => $tx }, $cb) if $ct =~ m!^text/plain!;
-    return $c->$cb(Mojolicious::Plugin::LinkEmbedder::Link->new(url => $url));
-  });
+  $self->_ua->head(
+    $url,
+    sub {
+      my ($ua, $tx) = @_;
+      my $ct = $tx->res->headers->content_type || '';
+
+      return if $ct =~ m!^image/!     and $self->_new_link_object(image => $c, {url => $url, _tx => $tx},  $cb);
+      return if $ct =~ m!^video/!     and $self->_new_link_object(video => $c, {url => $url, _tx => $tx},  $cb);
+      return if $ct =~ m!^text/html!  and $self->_new_link_object(html  => $c, {url => $url, _tx => $tx,}, $cb);
+      return if $ct =~ m!^text/plain! and $self->_new_link_object(text  => $c, {url => $url, _tx => $tx},  $cb);
+
+      warn "[LINK] New from $ct: Mojolicious::Plugin::LinkEmbedder::Link\n" if DEBUG;
+      return $c->$cb(Mojolicious::Plugin::LinkEmbedder::Link->new(url => $url));
+    }
+  );
 
   return $c;
 }
 
 sub _new_link_object {
-  my($self, $type, $c, $args, $cb) = @_;
-  my $class = $self->{classes}{$type} || '';
+  my ($self, $type, $c, $args, $cb) = @_;
+  my $class = $self->{classes}{$type} or return;
   my $e = $LOADER->load($class);
 
-  warn "[LINK] new from $type: $class\n" if DEBUG;
+  warn "[LINK] New from $type: $class\n" if DEBUG;
 
-  if(!defined $e) {
+  if (!defined $e) {
     my $link = $class->new($args);
-    $link->{ua} = $self->_ua;
+    $link->ua($self->_ua);
     $link->learn($cb, $c, $link);
     return $class;
   }
@@ -165,56 +175,58 @@ while C<$obj> is a L<Mojolicious::Routes::Route> object.
 =cut
 
 sub register {
-  my($self, $app, $config) = @_;
+  my ($self, $app, $config) = @_;
 
   $self->{classes} = {
-    '2play' => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
-    'beta.dbtv' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
-    'blip' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip',
+    '2play'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
+    'beta.dbtv'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
+    'blip'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip',
     'collegehumor' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor',
-    'gist.github' => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
-    'image' => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
-    'imgur' => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
-    'ted' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted',
-    'text' => 'Mojolicious::Plugin::LinkEmbedder::Link::Text',
-    'twitter' => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter',
-    'video' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video',
-    'vimeo' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo',
-    'youtube' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube',
+    'gist.github'  => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
+    'html'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML',
+    'image'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
+    'imgur'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
+    'ted'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted',
+    'text'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text',
+    'twitter'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter',
+    'video'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video',
+    'vimeo'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo',
+    'youtube'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube',
   };
 
-  $app->helper(embed_link => sub { $self->embed_link(@_) });
+  $app->helper(
+    embed_link => sub {
+      return $self if @_ == 1;
+      return $self->embed_link(@_);
+    }
+  );
 
-  if(my $route = $config->{route}) {
+  if (my $route = $config->{route}) {
     $self->_add_action($app, $route);
   }
 }
 
 sub _add_action {
-  my($self, $app, $route) = @_;
+  my ($self, $app, $route) = @_;
 
-  unless(ref $route) {
+  unless (ref $route) {
     $route = $app->routes->route($route);
   }
 
-  $route->to(cb => sub {
-    my $c = shift->render_later;
+  $route->to(
+    cb => sub {
+      my $c = shift->render_later;
 
-    $c->embed_link($c->param('url'), sub {
-      my($c, $link) = @_;
+      $c->embed_link(
+        $c->param('url'),
+        sub {
+          my ($c, $link) = @_;
 
-      $c->respond_to(
-        json => {
-          json => {
-            media_id => $link->media_id,
-            pretty_url => $link->pretty_url,
-            url => $link->url->to_string,
-          },
-        },
-        any => { text => $link->to_embed },
+          $c->respond_to(json => {json => $link}, any => {text => $link->to_embed},);
+        }
       );
-    });
-  });
+    }
+  );
 }
 
 =head1 DISCLAIMER
